Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Ingestor ¶
type Ingestor interface {
// HealthCheck provides a mechanism for the client to check health of the provider.
HealthCheck(ctx context.Context) error
// Run starts the ingestion pipelines to ingest data provided by the collector into the intermediate store and graph database.
Run(ctx context.Context) error
// Close cleans up any resources used by the Provider implementation. Provider cannot be reused after this call.
Close(ctx context.Context) error
}
Ingestor is responsible for pulling data from the collector component and populating the store and graph databases.
func Factory ¶
func Factory(cfg *config.KubehoundConfig, collect collector.CollectorClient, c cache.CacheProvider, storedb storedb.Provider, graphdb graphdb.Provider) (Ingestor, error)
Factory creates a new ingestor instance from the provided configuration and service dependencies.
type PipelineIngestor ¶
type PipelineIngestor struct {
// contains filtered or unexported fields
}
PipelineIngestor is a parallelized pipeline based ingestor implementation.
func (PipelineIngestor) Close ¶
func (i PipelineIngestor) Close(ctx context.Context) error
Close cleans up any resources owned by the pipeline ingestor.
func (PipelineIngestor) HealthCheck ¶
func (i PipelineIngestor) HealthCheck(ctx context.Context) error
HealthCheck enables a check of the ingestor service dependencies.
Click to show internal directories.
Click to hide internal directories.